
class OrkgResponse(object):

    @property
    def succeeded(self):
        return str(self.status_code)[0] == '2'

    def __init__(self, response):
        self.status_code = response.status_code
        self.content = response.json() if len(response.content) > 0 else response.content
        self.url = response.url

    def __repr__(self):
        return "%s %s" % ("(Success)" if self.succeeded else "(Fail)", self.content)

    def __str__(self):
        return self.content



from orkg.utils import NamespacedClient, query_params, dict_to_url_params
from orkg.out import OrkgResponse


class PapersClient(NamespacedClient):

    def add(self, params=None):
        """
        Create a new paper in the ORKG instance
        :param params: paper Object
        :return: an OrkgResponse object containing the newly created paper resource
        """
        self.client.backend._append_slash = True
        response = self.client.backend.papers.POST(json=params, headers=self.auth)
        return OrkgResponse(response)

